@@ -121,6 +121,7 @@ from .usecases.human_activity_recognition import HumanActivityUseCase, HumanActi
 from .usecases.gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 from .usecases.license_plate_monitoring import LicensePlateMonitorConfig,LicensePlateMonitorUseCase
 from .usecases.dwell_detection import DwellConfig,DwellUseCase
+from .usecases.age_gender_detection import AgeGenderConfig, AgeGenderUseCase
 
 #Put all IMAGE based usecases here
 from .usecases.blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -185,7 +186,7 @@ from .usecases import (
     AbandonedObjectDetectionUseCase,
     LicensePlateMonitorUseCase,
     DwellUseCase,
-
+    AgeGenderUseCase,
 
     HumanActivityUseCase,
 
@@ -261,6 +262,7 @@ _human_activity_recognition = HumanActivityUseCase()
 _gas_leak_detection = GasLeakDetectionUseCase()
 _license_plate_monitor = LicensePlateMonitorUseCase()
 _dwell = DwellUseCase()
+_age_gender_detection = AgeGenderUseCase()
 
 
 #Put all IMAGE based usecases here
@@ -334,6 +336,7 @@ registry.register_use_case(_human_activity_recognition.category, _human_activity
 registry.register_use_case(_gas_leak_detection.category, _gas_leak_detection.name, GasLeakDetectionUseCase)
 registry.register_use_case(_license_plate_monitor.category, _license_plate_monitor.name, LicensePlateMonitorUseCase)
 registry.register_use_case(_dwell.category, _dwell.name, DwellUseCase)
+registry.register_use_case(_age_gender_detection.category, _age_gender_detection.name, AgeDetectionUseCase)
 
 #Put all IMAGE based usecases here
 registry.register_use_case(_blood_cancer_detection.category, _blood_cancer_detection.name, BloodCancerDetectionUseCase)
@@ -531,6 +534,7 @@ __all__ = [
     'HumanActivityConfig',
     'LicensePlateMonitorConfig',
     'DwellConfig',
+    'AgeGenderConfig',
 
     #Put all IMAGE based usecase CONFIGS here
     'BloodCancerDetectionConfig',
@@ -597,6 +601,7 @@ __all__ = [
     'GasLeakDetectionUseCase',
     'LicensePlateMonitorUseCase',
     'DwellUseCase',
+    'AgeGenderUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
