@@ -99,6 +99,7 @@ from .usecases import (
     WaterBodyUseCase,
     LicensePlateMonitorUseCase,
     DwellUseCase,
+    AgeGenderUseCase,
 
     #Put all IMAGE based usecases here
     BloodCancerDetectionUseCase,
@@ -242,6 +243,7 @@ class PostProcessor:
         registry.register_use_case("oil_gas", "gas_leak_detection", GasLeakDetectionUseCase)
         registry.register_use_case("license_plate_monitor", "license_plate_monitor", LicensePlateMonitorUseCase)
         registry.register_use_case("general", "dwell", DwellUseCase)
+        registry.register_use_case("age_gender_detection", "age_gender_detection", AgeGenderUseCase)
 
         #Put all IMAGE based usecases here
         registry.register_use_case("healthcare", "bloodcancer_img_detection", BloodCancerDetectionUseCase)
@@ -440,6 +442,8 @@ class PostProcessor:
                 result = use_case.process(data, parsed_config, input_bytes,context, stream_info)
             elif isinstance(use_case, DwellUseCase):
                 result = use_case.process(data, parsed_config,context, stream_info)
+            elif isinstance(use_case, AgeGenderUseCase):
+                result = use_case.process(data, parsed_config, input_bytes,context, stream_info)
             
             #Put all IMAGE based usecases here
             elif isinstance(use_case, BloodCancerDetectionUseCase):
