@@ -78,6 +78,7 @@ from .human_activity_recognition import HumanActivityConfig, HumanActivityUseCas
 from .gas_leak_detection import GasLeakDetectionConfig, GasLeakDetectionUseCase
 from .license_plate_monitoring import LicensePlateMonitorConfig,LicensePlateMonitorUseCase
 from .dwell_detection import DwellConfig,DwellUseCase
+from .age_gender_detection import AgeGenderConfig,AgeGenderUseCase
 
 #Put all IMAGE based usecases here
 from .blood_cancer_detection_img import BloodCancerDetectionConfig, BloodCancerDetectionUseCase
@@ -153,6 +154,7 @@ __all__ = [
     'GasLeakDetectionUseCase',
     'LicensePlateMonitorUseCase',
     'DwellUseCase',
+    'AgeGenderUseCase',
 
     #Put all IMAGE based usecases here
     'BloodCancerDetectionUseCase',
@@ -223,6 +225,7 @@ __all__ = [
     'LitterDetectionConfig',
     'AbandonedObjectConfig',
     'DwellConfig',
+    'AgeGenderConfig',
 
     'LeakDetectionConfig',
     'HumanActivityConfig',
