@@ -74,6 +74,9 @@ class WeaponDetectionUseCase(BaseProcessor):
         self.current_incident_end_timestamp: str = "N/A"
         self.start_timer = None
 
+        # Track start time for "TOTAL SINCE" calculation
+        self._tracking_start_time = None
+
     def process(self, data: Any, config: ConfigProtocol, context: Optional[ProcessingContext] = None,
                 stream_info: Optional[Dict[str, Any]] = None) -> ProcessingResult:
         start_time = time.time()
@@ -97,7 +100,14 @@ class WeaponDetectionUseCase(BaseProcessor):
             processed_data = apply_category_mapping(processed_data, config.index_to_category)
             self.logger.debug("Applied category mapping")
 
-        processed_data = self._check_weapon_objects(processed_data, config)
+        if config.target_weapon_categories:
+            processed_data = [d for d in processed_data if d.get('category') in self.target_categories]
+            self.logger.debug("Applied category filtering")
+
+        # Alert for detected weapons
+        for detection in processed_data:
+            if detection.get('category') in config.target_weapon_categories:
+                self.logger.warning(f"ALERT: {detection.get('category')} detected at {self._get_current_timestamp_str(stream_info)}")
 
         if config.enable_smoothing:
             if self.smoothing_tracker is None:
@@ -167,14 +177,6 @@ class WeaponDetectionUseCase(BaseProcessor):
         )
         return result
 
-    def _check_weapon_objects(self, data: List[Dict], config: WeaponDetectionConfig) -> List[Dict]:
-        weapon_data = []
-        for det in data:
-            if det.get('category') in config.target_weapon_categories:
-                det['category'] = 'weapon'
-                weapon_data.append(det)
-        return weapon_data
-
     def _check_alerts(self, summary: dict, frame_number: Any, config: WeaponDetectionConfig) -> List[Dict]:
         def get_trend(data, lookback=900, threshold=0.6):
             window = data[-lookback:] if len(data) >= lookback else data
@@ -337,7 +339,6 @@ class WeaponDetectionUseCase(BaseProcessor):
                 "settings": {t: v for t, v in zip(getattr(config.alert_config, 'alert_type', ['Default']),
                                                 getattr(config.alert_config, 'alert_value', ['JSON']))}
             })
-
         weapon_counts = {cat: per_category_count.get(cat, 0) for cat in config.target_weapon_categories}
 
         human_text_lines = [f"Tracking Statistics:"]
@@ -381,7 +382,7 @@ class WeaponDetectionUseCase(BaseProcessor):
             return []
         return []
 
-    def _generate_summary(self, counting_summary: Dict, incidents: List, tracking_stats: List, business_analytics: List, alerts: List) -> List[Dict]:
+    def _generate_summary(self, summary: dict, incidents: List, tracking_stats: List, business_analytics: List, alerts: List) -> List[Dict]:
         lines = {}
         lines["Application Name"] = self.CASE_TYPE
         lines["Application Version"] = self.CASE_VERSION
@@ -440,6 +441,7 @@ class WeaponDetectionUseCase(BaseProcessor):
 
     def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False, frame_id: Optional[str]=None) -> str:
         """Get formatted current timestamp based on stream type."""
+        
         if not stream_info:
             return "00:00:00.00"
         if precision:
@@ -449,6 +451,7 @@ class WeaponDetectionUseCase(BaseProcessor):
                 else:
                     start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
                 stream_time_str = self._format_timestamp_for_video(start_time)
+                
                 return self._format_timestamp(stream_info.get("input_settings", {}).get("stream_time", "NA"))
             else:
                 return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
@@ -458,7 +461,10 @@ class WeaponDetectionUseCase(BaseProcessor):
                 start_time = int(frame_id)/stream_info.get("input_settings", {}).get("original_fps", 30)
             else:
                 start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
+
             stream_time_str = self._format_timestamp_for_video(start_time)
+           
+
             return self._format_timestamp(stream_info.get("input_settings", {}).get("stream_time", "NA"))
         else:
             stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
@@ -514,27 +520,51 @@ class WeaponDetectionUseCase(BaseProcessor):
             dt = datetime.fromtimestamp(self._tracking_start_time, tz=timezone.utc)
             dt = dt.replace(minute=0, second=0, microsecond=0)
             return dt.strftime('%Y:%m:%d %H:%M:%S')
-
+        
     def _format_timestamp(self, timestamp: Any) -> str:
-        """Format a timestamp so that exactly two digits follow the decimal point (milliseconds)."""
+        """Format a timestamp so that exactly two digits follow the decimal point (milliseconds).
+
+        The input can be either:
+        1. A numeric Unix timestamp (``float`` / ``int``) – it will first be converted to a
+           string in the format ``YYYY-MM-DD-HH:MM:SS.ffffff UTC``.
+        2. A string already following the same layout.
+
+        The returned value preserves the overall format of the input but truncates or pads
+        the fractional seconds portion to **exactly two digits**.
+
+        Example
+        -------
+        >>> self._format_timestamp("2025-08-19-04:22:47.187574 UTC")
+        '2025-08-19-04:22:47.18 UTC'
+        """
+
+        # Convert numeric timestamps to the expected string representation first
         if isinstance(timestamp, (int, float)):
             timestamp = datetime.fromtimestamp(timestamp, timezone.utc).strftime(
                 '%Y-%m-%d-%H:%M:%S.%f UTC'
             )
 
+        # Ensure we are working with a string from here on
         if not isinstance(timestamp, str):
             return str(timestamp)
 
+        # If there is no fractional component, simply return the original string
         if '.' not in timestamp:
             return timestamp
 
+        # Split out the main portion (up to the decimal point)
         main_part, fractional_and_suffix = timestamp.split('.', 1)
+
+        # Separate fractional digits from the suffix (typically ' UTC')
         if ' ' in fractional_and_suffix:
             fractional_part, suffix = fractional_and_suffix.split(' ', 1)
-            suffix = ' ' + suffix
+            suffix = ' ' + suffix  # Re-attach the space removed by split
         else:
             fractional_part, suffix = fractional_and_suffix, ''
+
+        # Guarantee exactly two digits for the fractional part
         fractional_part = (fractional_part + '00')[:2]
+
         return f"{main_part}.{fractional_part}{suffix}"
 
     def _count_categories(self, detections: list, config: WeaponDetectionConfig) -> dict:
@@ -635,6 +665,52 @@ class WeaponDetectionUseCase(BaseProcessor):
         }
         return canonical_id
 
+    def _format_timestamp(self, timestamp: Any) -> str:
+        """Format a timestamp so that exactly two digits follow the decimal point (milliseconds).
+
+        The input can be either:
+        1. A numeric Unix timestamp (``float`` / ``int``) – it will first be converted to a
+           string in the format ``YYYY-MM-DD-HH:MM:SS.ffffff UTC``.
+        2. A string already following the same layout.
+
+        The returned value preserves the overall format of the input but truncates or pads
+        the fractional seconds portion to **exactly two digits**.
+
+        Example
+        -------
+        >>> self._format_timestamp("2025-08-19-04:22:47.187574 UTC")
+        '2025-08-19-04:22:47.18 UTC'
+        """
+
+        # Convert numeric timestamps to the expected string representation first
+        if isinstance(timestamp, (int, float)):
+            timestamp = datetime.fromtimestamp(timestamp, timezone.utc).strftime(
+                '%Y-%m-%d-%H:%M:%S.%f UTC'
+            )
+
+        # Ensure we are working with a string from here on
+        if not isinstance(timestamp, str):
+            return str(timestamp)
+
+        # If there is no fractional component, simply return the original string
+        if '.' not in timestamp:
+            return timestamp
+
+        # Split out the main portion (up to the decimal point)
+        main_part, fractional_and_suffix = timestamp.split('.', 1)
+
+        # Separate fractional digits from the suffix (typically ' UTC')
+        if ' ' in fractional_and_suffix:
+            fractional_part, suffix = fractional_and_suffix.split(' ', 1)
+            suffix = ' ' + suffix  # Re-attach the space removed by split
+        else:
+            fractional_part, suffix = fractional_and_suffix, ''
+
+        # Guarantee exactly two digits for the fractional part
+        fractional_part = (fractional_part + '00')[:2]
+
+        return f"{main_part}.{fractional_part}{suffix}"
+
     def _get_tracking_start_time(self) -> str:
         if self._tracking_start_time is None:
             return "N/A"
